@@ -164,9 +164,10 @@ def get_layer_files_to_process(pipe_control_var, trusted_layer_path, sink_name):
     month = base_date.split('-')[1]
     prefix = "{}year={}/month={}".format(sid_process_config['s3_prefix'], year, month)
 
-    trusted_layer_files = aws_utils.S3.s3_get_list_objects(
-        trusted_layer_path,
-        prefix)
+    s3_client = aws_utils.S3(bucket_name=trusted_layer_path)
+    trusted_layer_files = s3_client.s3_get_list_objects(
+        bucket=trusted_layer_path,
+        s3_prefix=prefix)
 
     return trusted_layer_files
 
@@ -218,7 +219,8 @@ def _task_send_file(files, **context):
             # s3://cortex-data-platform-trusted-area-dev/receita_federal/dados_abertos_cnpj/empresas/run-1632755590381-part-block-0-r-00000-snappy.parquet
             chunked = sid_file_chunk
 
-            dfs = aws_utils.wr_s3_read_parquet(s3_file_path, chunked)
+            s3_client = aws_utils.S3(bucket_name=s3_path)
+            dfs = s3_client.wr_s3_read_parquet(s3_file_path, chunked)
 
             for df in dfs:
                 df = rearrange_df_to_sid(df)
