@@ -5,6 +5,7 @@ import boto3
 import json
 from botocore.config import Config
 from botocore.errorfactory import ClientError
+import awswrangler as wr
 
 
 logger = logging.getLogger(__name__)
@@ -128,6 +129,14 @@ class S3:
         contents = response['Contents']
         return contents
 
+    def wr_s3_read_parquet(s3file_path: str, chunked: int):
+        session = boto3.Session(
+            region_name=DEFAULT_REGION
+        )
+        dfs = wr.s3.read_parquet(path=[s3file_path], chunked=chunked, boto3_session=session)    
+
+        return dfs
+
 class DataBrewClient:
     def __init__(self):
         self.client = boto3.client('databrew', region_name='us-east-1')
